==> ugene_1.25.0%2Bdfsg.orig.tar.xz: ugene-1.25.0/src/plugins/workflow_designer/src/debug_messages_translation/BaseMessageTranslator.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_BASE_MESSAGE_TRANSLATOR_H_
#define _U2_BASE_MESSAGE_TRANSLATOR_H_

#include <QtCore/QString>
#include <QtCore/QVariant>

namespace U2 {

namespace Workflow {

class WorkflowContext;

}

// the string is supposed to be used as separator
// between different pieces of information obtained from
// translated message
const QString INFO_TAGS_SEPARATOR = ";";
const QString INFO_FEATURES_SEPARATOR = ",";

/* The type is intended for converting messages' content into QString
for visualizing them during a scheme's execution */

class BaseMessageTranslator {
public:
    BaseMessageTranslator( const QVariant &atomicMessage, Workflow::WorkflowContext *initContext );
    virtual ~BaseMessageTranslator( );

    virtual QString getTranslation( ) const;

protected:
    const QVariant source;
    Workflow::WorkflowContext *context;
};

} // namespace U2

#endif // _U2_BASE_MESSAGE_TRANSLATOR_H_

==> ugene_51.0%2Bdfsg.orig.tar.xz: ugene-51.0/src/plugins/workflow_designer/src/debug_messages_translation/BaseMessageTranslator.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include <QString>
#include <QVariant>

namespace U2 {

namespace Workflow {

class WorkflowContext;

}

// the string is supposed to be used as separator
// between different pieces of information obtained from
// translated message
const QString INFO_TAGS_SEPARATOR = ";";
const QString INFO_FEATURES_SEPARATOR = ",";

/* The type is intended for converting messages' content into QString
for visualizing them during a scheme's execution */

class BaseMessageTranslator {
public:
    BaseMessageTranslator(const QVariant& atomicMessage, Workflow::WorkflowContext* initContext);
    virtual ~BaseMessageTranslator();

    virtual QString getTranslation() const;

protected:
    const QVariant source;
    Workflow::WorkflowContext* context;
};

}  // namespace U2
